@@ -1,3 +1,4 @@
+import os
 from django.conf.urls import *
 from alto import views
 
@@ -7,5 +8,8 @@ urlpatterns = patterns('',
     url(r'urlpatterns/$', views.url_patterns),
     url(r'template-paths/$', views.templates),
     url(r'(?P<mode>\w+)/$', views.index),
+    url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {
+        'document_root': os.path.join(os.path.dirname(__file__), 'static'),
+    }),
     url(r'$', views.index),
 )
